#---- Profile Setup
    # View the different types(scopes) of profiles
        $profile | gm -type NoteProperty
    # View current session profile
        $profile
    # Check if you already have a profile file created
        test-path -path $profile.CurrentUserCurrentHost
    # Create new profile file
        New-Item -ItemType file -path $profile -Force

# View the Script that sets your current prompt
    (Get-Command Prompt).ScriptBlock

# Show Aliases
    Get-Alias | Select-Object -First 10
    Remove-Item Alias:ls

# Show Functions
    Get-Command mkdir |Format-List -Property Name, Definition
    Get-ChildItem Function:\mkdir | Format-List ScriptBlock

# ------------------------------------------------------------------------------------------------#
# ------------------------------------------------------------------------------------------------#
# ------------------------------------Demo Profile------------------------------------------------#
# ------------------------------------------------------------------------------------------------#
# ------------------------------------------------------------------------------------------------#

# Find out if the current user identity is elevated (has admin rights)
$identity = [Security.Principal.WindowsIdentity]::GetCurrent()
$principal = New-Object Security.Principal.WindowsPrincipal $identity
$isAdmin = $principal.IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)

# If so and the current host is a command line, then change to red color 
# as warning to user that they are operating in an elevated context
if (($host.Name -match "ConsoleHost") -and ($isAdmin))
{
     $host.UI.RawUI.BackgroundColor = "DarkRed"
     $host.PrivateData.ErrorBackgroundColor = "White"
     $host.PrivateData.ErrorForegroundColor = "DarkRed"
     Clear-Host
}

# Set up command prompt and window title. Use UNIX-style convention for identifying 
# whether user is elevated (root) or not. Window title shows current version of PowerShell
# and appends [ADMIN] if appropriate for easy taskbar identification
function prompt 
{ 
    if ($isAdmin) 
    {
        "[" + (Get-Location) + "] # " 
    }
    else 
    {
        "[" + (Get-Location) + "] $ "
    }
}

$Host.UI.RawUI.WindowTitle = "PowerShell {0}" -f $PSVersionTable.PSVersion.ToString()
if ($isAdmin)
{
    $Host.UI.RawUI.WindowTitle += " [ADMIN]"
}

# Change Directory to 'c:\users\user\'
cd $home

# Compute file hashes - useful for checking successful downloads 
function md5    { Get-FileHash -Algorithm MD5 $args }
function sha1   { Get-FileHash -Algorithm SHA1 $args }
function sha256 { Get-FileHash -Algorithm SHA256 $args }
function less
{
  Get-Content $args[0] | Out-Host -Paging
}

#Set-Alias -Name  -Value
Set-Alias -Name gh -Value Get-Help
Set-Alias -Name so -Value Select-Object
Set-Alias -Name c -Value Clear-Host
Set-Alias -Name l -Value Get-ChildItem
