#!/bin/bash
  : '   # File  :         compressions.sh
        # Name  :         Greg Shrewsbury
        # Date  :         21Apr2020
        # Desc  :         Provide description of file compression types in liunx
        # Usage :         ./script.sh OR source script.sh'

# --- COLOR VARIABLES AND FUNCTIONS --- #
    export NC='\e[0m'               # Text Reset
    export BBlack='\e[1;30m'        # Black
    export BRed='\e[1;31m'          # Red
    export BGreen='\e[1;32m'        # Green
    export BYellow='\e[1;33m'       # Yellow
    export BBlue='\e[1;34m'         # Blue
    export BPurple='\e[1;35m'       # Purple
    export BCyan='\e[1;36m'         # Cyan
    export BWhite='\e[1;37m'        # White
    export NC='\e[0m'               # Text Reset
    export Black='\e[0;30m'         # Black
    export Red='\e[0;31m'           # Red
    export Green='\e[0;32m'         # Green
    export Yellow='\e[0;33m'        # Yellow
    export Blue='\e[0;34m'          # Blue
    export Purple='\e[0;35m'        # Purple
    export Cyan='\e[0;36m'          # Cyan
    export White='\e[0;37m'         # White

    function comm { echo -e "${BGreen}${1}${NC}"
    }
    function cli { echo -e "${Red}# ${1}${NC}"
    }
    function label { echo -e "${BBlue}${1}${NC}"
    }
    function output { echo -e "${NC}${1}\n"
    }

# --- Functions --- #
    reset

# ----- 7zip ----- #
about_7z () {
    reset

    label '# --- *.7zip --- #\n'
    comm '# Save 3 files to a folder and confirm with an "ls"'
    cli 'export FOLDER="test"; export ARCHIVE_NAME="test.7z"'
    cli 'mkdir $FOLDER'
    cli 'for i in file_{1..3}; do echo "Hello, World" >> ./$FOLDER/${i}.txt; done'
    cli 'ls -l ./$FOLDER'

    output \
'total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt'

    comm '# Use "7zip" to archive the folder.'
    cli '7z a $ARCHIVE_NAME $FOLDER'

    output \
'Scanning the drive:
1 folder, 3 files, 0 bytes

Creating archive: temp.7z
Items to compress: 4
Files read from disk: 0

Archive size: 154 bytes (1 KiB)'

    comm 'Confirm the archive was made'
    cli 'ls -l test*'

    output \
'drwxr-xr-x 2 root root 4096 Apr 27 18:16 test
-rw-r--r-- 1 root root  154 Apr 27 18:23 test.7z'

    comm 'Extract the archive, and save the contents to a different directory'
    cli 'NEW_FOLDER=Temp'
    cli '7z -o${NEW_FOLDER} x test.7z'
    cli 'ls -l ./$NEW_FOLDER'

    output \
'total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt'
}

 # ----- Gzip ----- #
about_gzip () {
    reset

    label '# --- *.gzip --- #\n'
    comm '# Save 3 files to a folder and confirm with an "ls"'
    cli 'export FOLDER="test"; export ARCHIVE_NAME=test.gz'
    cli 'mkdir $FOLDER'
    cli 'for i in file_{1..3}; do echo \"Hello, World\" >> ./$FOLDER/${i}.txt; done'
    cli 'ls -l ./$FOLDER'

    output \
"-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt"

    comm '# Use "gzip" to compress the file.'
    cli 'cd $FOLDER'
    cli 'gzip file_1.txt'
    comm 'Confirm the zip file was made'
    cli 'ls -l'

    output \
"-rw-r--r-- 1 root root 44 Apr 28 10:09 file_1.txt.gz
-rw-r--r-- 1 root root 44 Apr 28 10:09 file_2.txt
-rw-r--r-- 1 root root 13 Apr 28 10:09 file_3.txt"

    comm '#Or use "gzip" on multiple files'
    cli 'gzip file_2.txt file_3.txt'
    comm 'Confirm the zip file was made'
    cli 'ls -l'

    output \
"-rw-r--r-- 1 root root 44 Apr 28 10:09 file_1.txt.gz
-rw-r--r-- 1 root root 44 Apr 28 10:09 file_2.txt.gz
-rw-r--r-- 1 root root 13 Apr 28 10:09 file_3.txt.gz"

    comm '# Use "gunzip" like g-unzip to decompress the file.'
    cli 'gunzip file_2.txt.gz file_3.txt.gz'
    comm '#Confirm zip was decompressed'
    cli 'ls -l'

    output \
"-rw-r--r-- 1 root root 44 Apr 28 10:09 file_1.txt
-rw-r--r-- 1 root root 44 Apr 28 10:10 file_2.txt
-rw-r--r-- 1 root root 13 Apr 28 10:10 file_3.txt"

}

# ----- Bzip2 ----- #
about_bzip2 () {
    reset

    label '# --- *.bzip2 --- #\n'
    comm '# Save 3 files to a folder and confirm with an "ls"'
    cli 'export FOLDER="test"; export ARCHIVE_NAME=test.bz2'
    cli 'mkdir $FOLDER'
    cli 'for i in file_{1..3}; do echo \"Hello, World\" >> ./$FOLDER/${i}.txt; done'
    cli 'ls -l ./$FOLDER'

    output \
'total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt'

    comm '# Use "bzip" to archive the folder.'
    cli 'cd test'
    cli 'bzip2 file_1.txt'

    output \
'total
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt.bz2
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt'

    comm '# Or use "bzip2"on multiple files'
    cli 'bzip2 file_2.txt file_3.txt'
    comm '# Confirm the bzip2 file was made'
    cli 'ls -l'

    output \
'total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt.bz2
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt.bz2
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt.bz2'

    comm '# Use "bzip2" to decompress a zipped file'
    cli 'bzip2 -d file_1.txt.bz2 file_2.txt.bz2'
    comm '# Use extacted bzip2 as input for other file type.'
    cli 'bzip2 -d file_3.txt.bz2 | gzip file_3.txt | 7z a test'
    comm '# Confirm files were changed.'
    cli 'ls -l'

    output \
'-rw-r--r-- 1 root root 195 Apr 28 18:03 test.7z
-rw-r--r-- 1 root root  13 Apr 28 17:05 file_1.txt
-rw-r--r-- 1 root root  13 Apr 28 17:05 file_2.txt
-rw-r--r-- 1 root root  13 Apr 28 17:05 file_3.txt'

    comm '# Decrompress all'
    cli '7z x test.7z'
    comm '# Confirm all files returned'
    cli 'ls -l'

    output \
'-rw-r--r-- 1 root root 13 Apr 28 17:05 file_1.txt
-rw-r--r-- 1 root root 13 Apr 28 17:05 file_2.txt
-rw-r--r-- 1 root root 13 Apr 28 17:05 file_3.txt'

}

# ----- Tar ----- #
about_tar () {
    reset
    
    label '# --- *.tar --- #\n'
    comm '# Save 6 files to a folder and confirm with an "ls"'
    cli 'export FOLDER="test"; export ARCHIVE_NAME=test.tar'
    cli 'mkdir $FOLDER'
    cli 'for i in file_{1..3}; do echo \"Hello, World\" >> ./$FOLDER/${i}.txt; done'
    cli 'for i in file_{1..3}; do echo \"Hello, World\" >> ./$FOLDER/${i}.jpg; done'
    cli 'ls -l ./$FOLDER'
    
    output \
'-rw-r--r-- 1 root root 15 May  5 11:02 file_1.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_1.txt
-rw-r--r-- 1 root root 15 May  5 11:02 file_2.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_2.txt
-rw-r--r-- 1 root root 15 May  5 11:02 file_3.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_3.txt'
    
    comm '# Use "tar" to archive the folder.' # To create an uncompressed archive #
    cli 'cd test'
    cli 'tar -cvf target.tar *.txt *.jpg'
    cli 'ls -l'

    output \
'-rw-r--r-- 1 root root 15 May  5 11:02 file_1.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_1.txt
-rw-r--r-- 1 root root 15 May  5 11:02 file_2.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_2.txt
-rw-r--r-- 1 root root 15 May  5 11:02 file_3.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_3.txt
-rw-r--r-- 1 root root 10240 May  5 11:02 target.tar'
    
    cli 'rm *.jpg *.txt'
    cli 'ls -l'
    comm '# Shows that files are gone, now extract files to original to specified diectory with -C option and /path/to/directory or use <.> for current directory'
    cli 'tar -xf target.tar -C .' # To extract plane tar file #
    cli 'ls -l'
    
    output \
'-rw-r--r-- 1 root root 15 May  5 11:02 file_1.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_1.txt
-rw-r--r-- 1 root root 15 May  5 11:02 file_2.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_2.txt
-rw-r--r-- 1 root root 15 May  5 11:02 file_3.jpg
-rw-r--r-- 1 root root 15 May  5 11:02 file_3.txt
-rw-r--r-- 1 root root 10240 May  5 11:02 target.tar'
    
    comm '# Create a .gz tar archive' # To create a .gz archive #
    cli 'tar -czvf target2.tar *.jpg *.txt'
    cli 'ls -l'
    
    output \
'-rw-r--r-- 1 root root 10240 May  5 11:02 target.tar'
    
    comm '# file target2.tar to ensure zip comression worked'
    cli 'file target2.tar'
    
    output \
'target.tar: gzip compressed data, last modified: Tue May  5 14:31:58 2020, from Unix, original size 10240'
    
    comm '# To extract a .gz archive:' # To extract .gz from .tar #
    cli 'gunzip target.tar to decompress zipped archive'
    
    output \
'gzip: target.tar: unknown suffix -- ignored'
    
    comm '#gz files must have .gz at end to be recocnized'
    cli \
'mv target2.tar target2.tar.gz then gunzip target2.tar.gz
file target2.tar
ls -l
rm *.jpg *.txt
ls -l
tar -xf target.tar -C .
ls -l
rm -rf target.tar target2.tar target3.gz'
    
    comm '# To create a .gz archive and exclude certain files' # To create a .gz archive and exclude all jpg,gif,... from the tgz #
    cli 'tar czvf target3.gz --exclude=\*.{jpg,gif,png,wmv,flv,tar.gz,zip} .'
    cli 'rm *.txt'
    cli 'ls -l'
    comm '# ls -l will show that all text files are gone.'
    comm '# To show contents of .gz archive.' # To list the content of an .gz archive #
    cli 'tar -tvf target3.gz'
    
    output \
'-rw-r--r-- root root 15 2020-05-06 09:58 ./file_2.txt
-rw-r--r-- root root 15 2020-05-06 09:58 ./file_1.txt
-rw-r--r-- root root 15 2020-05-06 09:58 ./file_3.txt'
    
    comm '# Follow previous steps for .gz and .tar decompression'
    cli 'rm target3.gz'
    comm '# To create a .bz2 archive.' # To create a .bz2 archive #
    cli 'tar -cjvf target *jpg .'
    cli 'ls -l'
    cli 'file target'
    
    output \
'target: bzip2 compressed data, block size = 900k'
    
    cli 'rm *.jpg'
    comm '# To extract a .bz2 archive' #To extract a .bz2 archive #
    cli 'tar xjvf target.tar.bz2'
    comm '# Remember file types must have extensions to be decompressed'
    cli 'mv target target.tar.bz2'
    cli 'tar xjvf target.tar.bz2'
    cli 'ls -l'
    
    output \
'-rw-r--r-- 1 root root  15 May  7 09:09 file_1.jpg
-rw-r--r-- 1 root root  15 May  7 09:09 file_2.jpg
-rw-r--r-- 1 root root  15 May  7 09:09 file_3.jpg
-rw-r--r-- 1 root root   0 May  7 09:14 target
-rw-r--r-- 1 root root 303 May  7 09:14 target.tar.bz2'
}

# --- Main --- #

mainMenu () {
reset
while :
do
        echo
        echo -e "${BCyan}Choose from the following options:"
        echo -e "${BGreen}# ---------------------------------- #${NC}"
        echo "   [1] *.7z"
        echo "   [2] *.gzip"
        echo "   [3] *.bzip2"
        echo "   [4] *.tar"
        echo
        echo -e "${BPurple}   [X] to Exit : [C] to Clear the Screen${NC}" && echo
        read -p 'Choice:  ' choice
        echo
        case $choice in
            1) about_7z
                      ;;
            2) about_gzip
                      ;;
            3) about_bzip2
                      ;;
            4) about_tar
                      ;;
            [xX]) return 0
                      ;;
            [cC])  reset
                      ;;
            *) echo "Please enter a valid option"
                      ;;
      esac
      echo -e '\n\n\n'
done
}
# RUN THE PROGRAM
mainMenu
