#!/bin/bash
if : ; then
# File:         hello.sh
# Name:         Kevin Crotty
# Date:         23 Mar 2019
# Desc:         Bash Expansion Demo's
# Usage:        ./hello.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi
reset
dir=$PWD
colorComment "# Display default PATH, and save a backup"
colorCommand "echo \$PATH"
echo -e "/usr/sbin:/usr/bin:/sbin:/bin"
colorCommand "BAK=\$PATH"

colorComment "# Make a temporary folder to add to the PATH"
colorCommand "mkdir /tmp/myBin"
colorCommand "cd /tmp/myBin"

colorComment "# Append our new directroy to the end of the path"
colorCommand "PATH=\$PATH:\$PWD"
colorCommand "echo \$PATH"
echo -e "/usr/sbin:/usr/bin:/sbin:/bin:/tmp/myBin"

colorComment "# Reset the PATH variable and add our directory to the beginning of the PATH"
colorCommand "PATH=\$BAK"
colorCommand "echo \$PATH"
echo -e "/usr/sbin:/usr/bin:/sbin:/bin"
colorCommand "PATH=\$PWD:\$PATH"
colorCommand "echo \$PATH"
echo -e "/tmp/myBin:/usr/sbin:/usr/bin:/sbin:/bin"

colorComment "# Create 3 different types of 'hello' commands"
colorCommand "cd ~"
colorCommand "alias hello=\"echo hello from alias\" ${BPurple}<-- Alias${NC}"
colorCommand "function hello { echo \"hello from function\"; } ${BPurple}<-- Function${NC}"
colorCommand "echo \"echo hello from script\" > /tmp/myBin/hello && chmod +x /tmp/myBin/hello ${BPurple}<-- File${NC}"

colorComment "# 'type' will show what will happen when commands are ran (In Order)"
colorCommand "type hello"
echo -e "hello is aliased to 'echo hello from alias'"
colorCommand "type -a hello"
echo -e "hello is aliased to 'echo hello from alias'"
echo -e "hello is a function"
echo -e "hello () "
echo -e "{ "
echo -e "    echo \"hello from function\""
echo -e "}"
echo -e "hello is /tmp/myBin/hello"


colorComment "# First run of 'hello'"
colorCommand "hello"
echo -e "hello from alias"
colorCommand "unalias hello"


colorComment "# Second run of 'hello'"
colorCommand "hello"
echo -e "hello from function"
colorCommand "unset hello"

colorComment "# Third run of 'hello'"
colorCommand "hello"
echo -e "hello from script"
colorCommand "rm /tmp/myBin/hello"

colorComment "# Fourth run of 'hello'"
colorCommand "hello"
echo -e "-bash: /tmp/myBin/hello: No such file or directory"
colorCommand "hash"
echo -e "hits	command"
echo -e "   1	/bin/rm"
echo -e "   1	/bin/chmod"
echo -e "   2	/tmp/myBin/hello"
colorCommand "hash -r"

colorComment "# Fifth and Final run of 'hello'"
colorCommand "hello"
echo -e "-bash: hello: command not found"

cd $dir
