#!/bin/bash

# --- COLOR VARIABLES AND FUNCTIONS --- #
    reset
    export NC='\e[0m'               # Text Reset
    export BBlack='\e[1;30m'        # Black
    export BRed='\e[1;31m'          # Red
    export BGreen='\e[1;32m'        # Green
    export BYellow='\e[1;33m'       # Yellow
    export BBlue='\e[1;34m'         # Blue
    export BPurple='\e[1;35m'       # Purple
    export BCyan='\e[1;36m'         # Cyan
    export BWhite='\e[1;37m'        # White
    export NC='\e[0m'               # Text Reset
    export Black='\e[0;30m'         # Black
    export Red='\e[0;31m'           # Red
    export Green='\e[0;32m'         # Green
    export Yellow='\e[0;33m'        # Yellow
    export Blue='\e[0;34m'          # Blue
    export Purple='\e[0;35m'        # Purple
    export Cyan='\e[0;36m'          # Cyan
    export White='\e[0;37m'         # White

    function comm { echo -e "${BGreen}${1}${NC}"
    }
    function cli { echo -e "${Red}# ${1}${NC}"
    }
    function label { echo -e "${BBlue}${1}${NC}"
    }
    function output { echo -e "${NC}${1}\n"
    }

# --- Functions --- #

debug () {
reset

    label "--- Bash Debugging ---\n"
    comm '# Debug an entire script'
    cli 'bash -x demo.sh'
    comm "\n#  Debug parts of code in a script (Also works from CLI)"
    comm "#+ The lines starting with a '+' are for debugging only"
    cli \
'set -x
# for i in {1..3}
>do
>    if (( $i < 3 )); then
>        echo True
>    else
>        echo False
>    fi
>done
# set +x'

    output \
'+ for i in {1..3}
+ ((  1 < 3  ))
+ echo True
True
+ for i in {1..3}
+ ((  2 < 3  ))
+ echo True
True
+ for i in {1..3}
+ ((  3 < 3  ))
+ echo False
False'
}

conditional () {
reset

    label "--- Bash Conditionals ---\n"
    comm '# Use "if" to compare strings'

    cli \
'STRING_1="true"
# if [ "$STRING_1" = true ]; then
>    echo "The strings match"
>fi'
    
    output 'The strings match'
    comm '# Use "if", to check other criteria (man test)'

    cli \
'FILE_1=/etc/passwd
# if [ -f "$file" ]; then
>    echo file exists
>fi'

    output 'file exists'

comm '# Use the "test" command to condense If statements'
    cli 'test -f /etc/passwd && echo "file exists"'
    output 'file exists'

}

rc () {
reset

    label "--- RC File Usage ---\n"
    comm '# Set Environment Variables in a stand-alone file'
    cli 'cat variables.rc'
    
    output \
'# These variables can be used in other scripts
    export RED_PILL="true"
    export PROJECT_NAME="the_matrix"
    export USER_NAME="neo"
    export PASSWORD="tR1nITE"'

    comm '# Source the rc file from a script to make the variables available in that process'
    cli 'cat script.sh'
    
    output \
'#/bin/bash

# Set variables
    source variables.rc

# Run commmands based on rc file values
    if [ "$RED_PILL" = "true" ]; then
        sshpass -p $PASSWORD ssh $USER_NAME@$PROJECT_NAME.dotr -p333 -X    
    fi'
}

com_sub () {
reset

    label "--- Command Substitution ---\n"
    comm '# Use command substitution to populate the indexes of a For Loop'

    cli \
'for line in $(cat $FILENAME)
>do
>    echo $line
>done'

    comm "\n# Use command substitution to return the STDOUT of a function similar to a return value"

    cli \
'function greater_than_3 () {
>    if (( $1 > 3 )); then
>        echo "The number $1 is greater than 3"
>    else
>        echo 'NOPE'
>    fi }'

    comm "# Call function from within a For Loop"
    
    cli \
'for num in {2..4}
>do
>    echo $(greater_than_3 ${num})
>done'

    output \
'NOPE
NOPE
The number 4 is greater than 3'

    comm '# Pass multiple arguments to a command (in this case: 3 file names)'
    cli 'touch {1..3}.ajf'
    cli 'file $(find . -name "*.ajf")'

    output \
'./1.ajf: empty
./3.ajf: empty
./2.ajf: empty'
}

cur () {
reset

    label "--- CLI Cheatsheets ---\n"
    comm '# Use the curl command to display community created cheatsheets, hosted on the site "http://cht.sh", directly in your shell'
    cli 'curl cht.sh'

    output \
'      _                _         _    __
  ___| |__   ___  __ _| |_   ___| |__ \ \      The only cheat sheet you need    
 / __| |_ \ / _ \/ _` | __| / __| |_ \ \ \     Unified access to the best       
| (__| | | |  __/ (_| | |_ _\__ \ | | |/ /     community driven documentation   
 \___|_| |_|\___|\__,_|\__(_)___/_| |_/_/      repositories of the world        

+------------------------+ +------------------------+ +------------------------+
| $ curl cheat.sh/ls     | | $ cht.sh btrfs         | | $ cht.sh lua/:learn    |
| $ curl cht.sh/btrfs    | | $ cht.sh tar~list      | | Learn any* programming |
| $ curl cht.sh/tar~list | |                        | | language not leaving   |
| $ curl https://cht.sh  | |                        | | your shell             |
|                        | |                        | | *) any of 60           |
|                        | |                        | |                        |
+-- queries with curl ---+ +- own optional client --+ +- learn, learn, learn! -+
+------------------------+ +------------------------+ +------------------------+
| $ cht.sh go/f<tab><tab>| | $ cht.sh --shell       | | $ cht.sh go zip lists  |
| go/for   go/func       | | cht.sh> help           | | Ask any question using |
| $ cht.sh go/for        | | ...                    | | cht.sh or curl cht.sh: |
| ...                    | |                        | | /go/zip+lists          |
|                        | |                        | | (use /,+ when curling) |
|                        | |                        | |                        |
+---- TAB-completion ----+ +-- interactive shell ---+ +- programming questions-+
+------------------------+ +------------------------+ +------------------------+
| $ curl cht.sh/:help    | | $ vim prg.py           | | $ time curl cht.sh/    |
| see /:help and /:intro | | ...                    | | ...                    |
| for usage information  | | zip lists _            | | real    0m0.075s       |
| and README.md on GitHub| | <leader>KK             | |                        |
| for the details        | |             *awesome*  | |                        |
|            *start here*| |                        | |                        |
+--- self-documented ----+ +- queries from editor! -+ +---- instant answers ---+

[Follow @igor_chubin for updates][github.com/chubin/cheat.sh]'

    comm "\n# Use cht.sh/man to quickly get usage/syntax examples for the man command"
    cli 'curl cht.sh/man'

    output \
'# man
# Format and display manual pages.

# Display the man page for a command:
man command

# Display the man page for a command from section 7:
man command.7

# Display the path searched for manpages:
man --path

# Display the location of a manpage rather than the manpage itself:
man -w command

# Search for manpages containing a search string:
man -k "search string" '


    comm "\n# Use cht.sh/ls to quickly get usage/syntax examples for the ls command"
    cli 'curl cht.sh/ls'

    output \
'# ls
# List directory contents.

# List files one per line:
ls -1

# List all files, including hidden files:
ls -a

# Long format list (permissions, ownership, size and modification date) of all files:
ls -la

# Long format list with size displayed using human readable units (KB, MB, GB):
ls -lh

# Long format list sorted by size (descending):
ls -lS

# Long format list of all files, sorted by modification date (oldest first):
ls -ltr'

    comm "\n# Use cht.sh/grep to quickly get usage/syntax examples for the grep command"
    cli 'curl cht.sh/grep'

    output \
'# Grep
# Matches patterns in input text.
# Supports simple patterns and regular expressions.

# Search for an exact string:
grep search_string path/to/file

# Search in case-insensitive mode:
grep -i search_string path/to/file

# Search recursively (ignoring non-text files) in current directory for an exact string:
grep -v search_string'
}


# --- Main --- #

mainMenu () {
reset
while :
do
        echo
        echo -e "${BCyan}Choose from the following options:"
        echo -e "${BGreen}# ---------------------------------- #${NC}"
        echo "   [1] Bash Debugging"
        echo "   [2] Bash Conditionals"
        echo "   [3] RC File Usage"
        echo "   [4] Command Substitution"
        echo "   [5] CLI Cheatsheets"
        echo
        echo -e "${BPurple}   [X] to Exit : [C] to Clear the Screen${NC}" && echo
        read -p 'Choice:  ' choice
        echo
        case $choice in
            1) debug
                      ;;
            2) conditional
                      ;;
            3) rc
                      ;;
            4) com_sub
                      ;;
            5) cur
                      ;;

            [xX]) return 0
                      ;;
            [cC])  reset
                      ;;
            *) echo "Please enter a valid option"
                      ;;
      esac
      echo -e '\n\n\n'
done
}
# RUN THE PROGRAM
mainMenu
