# File:     ads-basics.ps1
# Name:     Joseph.Gerwing
# Date:     20200731
# Desc:     Creating and Viewing Alternate Data Streams
# Usage:    powershell_ise.exe .\ads-basics.ps1 (Be in an elevated PowerShell ISE prompt)
# Note:     Script is meant to be ran incrementally using PowerShell ISE's 'run selection' or 'F8' option for each line in script

#---- Creating and Viewing Alternate Data Streams via Command Prompt ----#
# This section requires individual to open an admin CMD shell.

#-- Alternate Data Streams on a File --#

# Create a file 'reminder.txt' with content 'Always try your best'
echo Always try your best > reminder.txt

# Verify file and content exists
dir reminder.txt
type reminder.txt

# Add ADS content 'social security numbers' to reminder.txt
echo social security numbers > reminder.txt:secret.info

# Verify file and contents again - notice that the ADS 'social security numbers' does not show up.
dir reminder.txt
type reminder.txt

# If we are aware of an ADS...we can list its content and show file related information.
more < reminder.txt:secret.info
notepad reminder.txt:secret.info
dir /R reminder.txt

# Some applications/commands are still unable to show ADS content even when you know it is there.
type reminder.txt:secret.info

#-- Altnerate Data Streams on a Directory --#

# Create a directory 'kids' with ADS content 'top-secret information'
mkdir kids
echo top-secret information > kids:hidden.txt

# Verify ADS content
dir /R kids
more < kids:hidden.txt

#---- Creating and Viewing Alternate Data Streams via PowerShell ----#

# Create a file 'reminder.txt' with content 'Always try your best'
echo "Always do your best" > reminder.txt

# Verify file and content exists
Get-Childitem reminder.txt
Get-Content reminder.txt

# Add ADS content 'social security numbers' to reminder.txt
Set-Content reminder.txt -Value "social security numbers" -Stream secret.info

# Verify file and content exists - we still don't see ADS content
Get-Childitem reminder.txt
Get-Content reminder.txt

# Show file streams and list ADS content
Get-Item reminder.txt -Stream *
Get-content reminder.txt -Stream secret.info

