#!/bin/bash

# File:         qemu-boot.sh
# Name:         Joseph Gerwing
# Date:         20200213
# Desc:         Error handling for booting into fun.vdi
# Usage:        source qemu-boot.sh

# Colors Variables
export BRED="\e[91m"
export BGREEN="\e[92m"
export NC="\e[0m"

# Function for highlighting comments
colorcomment () {
  echo -e "${BGREEN}$1${NC}"
}

# Test to see if you are currently mounted,
if [[ -n $(df -h | egrep nbd0p1) ]] ; then
   echo -e "${BGREEN}Sorry, you forgot to unmount. Try ${BRED}umount \$HOME/fun${NC}"

# Test to see if you are currently connected.
elif [[ -n $(ls /dev/nbd0p1 2> /dev/null) ]] ; then
   echo -e "${BGREEN}Sorry, you forgot to disconnect.  Try ${BRED}qemu-nbd -d /dev/nbd0${NC}"

# Test to see if you are the right directory.
elif [[ ! -f fun.vdi ]] ;  then
   echo -e "${BGREEN}Sorry, you forgot to be in $HOME. Try ${BRED}cd${NC}"

# If all tests are good - boot into fun.vdi
else
echo -ne "${BGREEN}All clear to boot! Booting now..." && sleep .9 && echo -e "${BRED}qemu-system-i386 $PWD/fun.vdi -m 512 -enable-kvm -show-cursor -vga std${NC}" && sleep 3
qemu-system-i386 $PWD/fun.vdi -m 1G -enable-kvm -show-cursor -vga std
fi
