#!/bin/bash
if : ; then
# File:         daemon.sh
# Name:         Kevin Crotty
# Date:         29 Mar 2019
# Desc:         Show an example daemon process
# Usage:        ./daemon.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

reset

colorComment "# Shows User Mode Daemons(Orphans)"
echo -e "${BRed}ps --ppid 1 -lf | head${NC}"
echo -e "F S UID        PID  PPID  C PRI  NI ADDR SZ WCHAN  STIME TTY          TIME CMD"
echo -e "4 S root       310     1  0  79  -1 - 25836 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-journald"
echo -e "4 S root       336     1  0  80   0 -  8503 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-udevd"
echo -e "4 S systemd+   576     1  0  80   0 - 17750 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-resolved"
echo -e "4 S systemd+   578     1  0  80   0 - 36527 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-timesyncd"
echo -e "5 S root       609     1  0  76  -4 -  7994 ep_pol 18:23 ?        00:00:00 /sbin/auditd"
echo -e "4 S root       876     1  0  80   0 - 17678 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-logind"
echo -e "4 S root       877     1  0  80   0 -  1138 poll_s 18:23 ?        00:00:02 /usr/sbin/acpid"
echo -e "4 S root       900     1  0  80   0 -  9607 hrtime 18:23 ?        00:00:00 /usr/sbin/cron -f"
echo -e "4 S syslog     882     1  0  80   0 - 65759 poll_s 18:23 ?        00:00:00 /usr/sbin/rsyslogd -n"

colorComment "# Shows the Source Files of the Daemons above"
echo -e "${BRed}ls -l /etc/init.d/ | head${NC}"
echo -e "total 196"
echo -e "-rwxr-xr-x 1 root root 2269 Apr 22  2017 acpid"
echo -e "-rwxr-xr-x 1 root root 5336 Jan 22  2017 alsa-utils"
echo -e "-rwxr-xr-x 1 root root 2014 May 29  2017 anacron"
echo -e "-rwxr-xr-x 1 root root 2802 Nov 20  2017 apport"
echo -e "-rwxr-xr-x 1 root root 3617 Dec 18  2017 auditd"
echo -e "-rwxr-xr-x 1 root root 2401 Aug 22  2018 avahi-daemon"
echo -e "-rwxr-xr-x 1 root root 2968 Feb  5  2018 bluetooth"
echo -e "-rwxr-xr-x 1 root root 1232 Apr 19  2018 console-setup.sh"
echo -e "-rwxr-xr-x 1 root root 3049 Nov 16  2017 cron"

colorComment "# View the cron startup script"
echo -e "${BRed}cat /etc/init.d/cron${NC}"
echo -e "#!/bin/sh"
echo -e "# Start/stop the cron daemon."
echo -e "#"
echo -e "### BEGIN INIT INFO"
echo -e "# Provides:          cron"
echo -e "# Required-Start:    \$remote_fs \$syslog \$time"
echo -e "# Required-Stop:     \$remote_fs \$syslog \$time"
echo -e "# Should-Start:      \$network \$named slapd autofs ypbind nscd nslcd winbind"
echo -e "# Should-Stop:       \$network \$named slapd autofs ypbind nscd nslcd winbind"
echo -e "# Default-Start:     2 3 4 5"
echo -e "# Default-Stop:"
echo -e "# Short-Description: Regular background program processing daemon"
echo -e "# Description:       cron is a standard UNIX program that runs user-specified"
echo -e "#                    programs at periodic scheduled times. vixie cron adds a"
echo -e "#                    number of features to the basic UNIX cron, including better"
echo -e "#                    security and more powerful configuration options."
echo -e "### END INIT INFO"

echo -e "PATH=/bin:/usr/bin:/sbin:/usr/sbin"
echo -e "DESC=\"cron daemon\""
echo -e "NAME=cron"
echo -e "DAEMON=/usr/sbin/cron"
echo -e "PIDFILE=/var/run/crond.pid"
echo -e "SCRIPTNAME=/etc/init.d/\"\$NAME\""
echo -e "${BCyan}<--Output Trimmed-->${NC}"

colorComment "# Stop the cron service and view the ps output"
echo -e "${BRed}/etc/init.d/cron stop${NC}"
echo -e "${BRed}ps --ppid 1 -lf | grep cron${NC}"
echo -e "${BCyan}<--No Output-->${NC}"

colorComment "# Start the cron service and view the ps output"
echo -e "${BRed}service cron start${NC}"
echo -e "${BRed}ps --ppid 1 -lf | grep cron${NC}"
echo -e "4 S root     31804     1  0  80   0 -  9607 hrtime 23:14 ?        00:00:00 /usr/sbin/cron -f"

colorComment "#  Restart -- does a Start then Stop (duh)"
echo -e "${BGreen}#+ Common to restart services to allow them to re-read config changes"
echo -e "${BRed}systemctl restart cron.service ${NC}"
echo -e "4 S root     31850     1  0  80   0 -  9607 hrtime 23:15 ?        00:00:00 /usr/sbin/cron -f\n\n"
