#!/bin/bash
if : ; then
# File:         zombie.sh
# Name:         Kevin Crotty
# Date:         29 Mar 2019
# Desc:         Demonstrate what a zombie process
# Usage:        ./zombie.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

reset

colorComment "# Show no running sleep processes"
echo -e "${BRed}ps -elf |grep -v grep | grep sleep${NC}"
echo -e "${BCyan}<--No Output-->${NC}"

colorComment "# Run our makeZombie.sh script"
echo -e "${BRed}./makeZombie.sh${NC}"
echo -e "echo \$\$"
echo -e "${BPurple}24345${NC}"
echo -e "\nsleep 5 &"
echo -e "\nsleep 15 &"
echo -e "\nps -elf |grep -v grep | grep sleep"
echo -e "0 S root     24346 ${BPurple}24345${NC}  0  80   0 -  3644 hrtime 21:26 pts/0    00:00:00 sleep 5"
echo -e "0 S root     24347 ${BPurple}24345${NC}  0  80   0 -  3644 hrtime 21:26 pts/0    00:00:00 sleep 15"
echo -e "\nsleep 1"
echo -e "\nkill -19 ${BPurple}24345${NC} ${BGreen}<-- kill -19 <pid> sends the SIGSTOP signal to pause the script before exiting${NC}"
echo -e "\n[1]+  Stopped                 ./zombie.sh"

colorComment "# Check For Zombies (Before 5 seconds)"
echo -e "${BRed}ps -elf |grep -v grep | grep sleep${NC}"
echo -e "0 S root     24346 ${BPurple}24345${NC}  0  80   0 -  3644 hrtime 21:26 pts/0    00:00:00 sleep 5"
echo -e "0 S root     24347 ${BPurple}24345${NC}  0  80   0 -  3644 hrtime 21:26 pts/0    00:00:00 sleep 15"

colorComment "# Check For Zombies (After 5 seconds, Before 15 Seconds)"
echo -e "${BRed}ps -elf |grep -v grep | grep sleep${NC}"
echo -e "0 Z root     24346 ${BPurple}24345${NC}  0  80   0 -     0 -      21:26 pts/0    00:00:00 [sleep] <defunct> ${BCyan}<-- Zombie${NC}"
echo -e "0 S root     24347 ${BPurple}24345${NC}  0  80   0 -  3644 hrtime 21:26 pts/0    00:00:00 sleep 15"

colorComment "# Check For Zombies (After 15 Seconds)"
echo -e "${BRed}ps -elf |grep -v grep | grep sleep${NC}"
echo -e "0 Z root     24346 ${BPurple}24345${NC}  0  80   0 -     0 -      21:26 pts/0    00:00:00 [sleep] <defunct> ${BCyan}<-- Zombie${NC}"
echo -e "0 Z root     24347 ${BPurple}24345${NC}  0  80   0 -     0 -      21:26 pts/0    00:00:00 [sleep] <defunct> ${BCyan}<-- Zombie${NC}"

colorComment "# Allows the script to resume and recognize that the sleep commands finished"
echo -e "${BRed}kill -18 ${BPurple}24345${NC} ${BGreen}<-- # 'kill -18 <pid>' sends the SIGCONT signal ${NC}"
echo -e "[1]+  Done                    ./zombie.sh"

colorComment "# All Process output is clean again"
echo -e "${BRed}ps -elf |grep -v grep | grep sleep${NC}"
echo -e "${BCyan}<--No Output-->${NC}\n\n"
