# File:     artifacts.ps1
# Name:     Joseph Gerwing
# Date:     20200903
# Desc:     Enumerate Windows Artifacts
# Usage:    powershell_ise.exe .\artifacts.ps1 (Be in an elevated PowerShell ISE prompt)
# Note1:    Script is meant to be ran incrementally using PowerShell ISE's 'run selection (F8)'
# Note2:    All artifact demos done on Workstation2 while pssession from the Admin-Station

#----Getting SIDs of Users and Importance

#-- PowerShell
get-wmiobject win32account | select name,sid
get-localuser | select Name,SID

#-- Get user SIDs with CMD
wmic useraccount get name,sid

#---- UserAssist

#-- CEBFF5CD: Executable File Execution

# Current User
Get-ItemProperty "HKCU:\Software\Microsoft\Windows\CurrentVersion\Explorer\UserAssist\{CEBFF5CD-ACE2-4F4F-9178-9926F41749EA}\Count"

# Every user on the system
Get-ItemProperty 'Registry::\HKEY_USERS\*\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\UserAssist\{CEBFF5CD-ACE2-4F4F-9178-9926F41749EA}\Count' -ErrorAction Continue

#-- F4E57C4B: Shortcut File Execution
Get-ItemProperty "HKCU:\Software\Microsoft\Windows\CurrentVersion\Explorer\UserAssist\{F4E57C4B-2036-45F0-A9AB-443BCFE33D9F}\Count"

#---- Windows Background Activity Moderator (BAM)

#-- Every user on the system (Windows 1709 & 1803)
Get-Item HKLM:\SYSTEM\CurrentControlSet\Services\bam\UserSettings\*

#-- Every user on the system (Windows 1809 and newer)
Get-Itemproperty 'HKLM:\SYSTEM\CurrentControlSet\Services\bam\state\UserSettings\*'

#---- Recycle Bin

#-- List directories and file of the Recycle Bin
Get-Childitem 'C:\$RECYCLE.BIN' -Recurse -Verbose -Force | select FullName
gci 'C:\$RECYCLE.BIN' -Recurse -Verbose -Force | select *
gci 'C:\$RECYCLE.BIN' -Recurse -Force

#-- Read the contents of a file in Recycle Bin
gc 'C:\$Recycle.Bin\$SID\$R*.txt'
gc 'C:\$Recycle.Bin\$SID\$I*.txt'

#---- Prefetch

# List first 80 items in prefetch location
Get-Childitem -Path 'C:\Windows\Prefetch' -ErrorAction Continue | select -First 80

#---- Jump Lists

# List the Programs/Items recently used
Get-Childitem -Recurse C:\Users\*\AppData\Roaming\Microsoft\Windows\Recent -ErrorAction Continue | select FullName, LastAccessTime
Get-Childitem -Recurse $env:USERPROFILE\AppData\Roaming\Microsoft\Windows\Recent -ErrorAction SilentlyContinue | select FullName,LastAccessTime

#---- Recent Files

#-- Query the hex value stored in the key
Get-Item 'Registry::\HKEY_USERS\*\Software\Microsoft\Windows\CurrentVersion\Explorer\RecentDocs\.txt'

#-- Convert a single value from hex to unicode (so we can read it)
[System.Text.Encoding]::Unicode.GetString((gp "REGISTRY::HKEY_USERS\*\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\RecentDocs\.txt")."0")

#-- Convert all user values from hex to unicode.
# Note: You may change/manipulate the extensions (i.e .txt) to different extensions to view different sets of information.
Get-Item "REGISTRY::HKEY_USERS\*\Software\Microsoft\Windows\CurrentVersion\Explorer\RecentDocs\.txt" | select -Expand property | ForEach-Object {
    [System.Text.Encoding]::Default.GetString((Get-ItemProperty -Path "REGISTRY::HKEY_USERS\*\Software\Microsoft\Windows\CurrentVersion\Explorer\RecentDocs\.txt" -Name $_).$_)
}

#---- Browser Artifacts

#-- Frequency
./strings 'C:\users\student\AppData\Local\Google\Chrome\User Data\Default\History'

#-- Most Visited
./strings 'C:\users\student\AppData\Local\Google\Chrome\User Data\Default\Top Sites'

#-- Current Session (Tabs) Note: Browser must be closed.
./strings 'C:\users\student\AppData\Local\Google\Chrome\User Data\Default\Current Session'

#-- User Name
./strings  'C:\users\student\AppData\Local\Google\Chrome\User Data\Default\Login Data'

#-- FQDN and if Sysinternals tools (i.e strings.exe) are not available
$History = (Get-Content 'C:\users\student\AppData\Local\Google\Chrome\User Data\Default\History') -replace "[^a-zA-Z0-9\.\:\/]","" # Store the content to $History
$History| Select-String -Pattern "(https|http):\/\/[a-zA-Z_0-9]+\.\w+[\.]?\w+" -AllMatches|foreach {$_.Matches.Groups[0].Value}| ft # Parse $History with patterns for URLs