# File:     audit-and-log.ps1
# Name:     Joseph Gerwing
# Date:     20200903
# Desc:     Show commands for Windows audit and logging.  Show PowerShell artifacts.
# Usage:    powershell_ise.exe .\artifacts.ps1 (Be in an elevated PowerShell ISE prompt)
# Note1:    Script is meant to be ran incrementally using PowerShell ISE's 'run selection (F8)'
# Note2:    All Auditing demos done on Admin-Station

#---- Audit Policy

#-- Viewing entire auditpol list
auditpol /get /category:*

#-- View and Enable Audit Object Access
auditpol /get /category:"Object Access"				# Show it
auditpol /set /subcategory:"File System"			# Set it
auditpol /set /subcategory:"File System" /success:disable	# Clear it

#-- List global object access auditing entries on..

# Files or Folders
auditpol /resourceSACL /type:File /view

# Registry Keys
auditpol /resourceSACL /type:Key /view

#---- Logs

#-- CMD
wevtutil el				# Show all logs
wevtutil gli security			# Get Security log info
wevtutil qe security /c:3 /f:text	# Get last 3 events from security log and view in human readable format

#-- PowerShell

# Get-Eventlog Way

  # List 10 newest entries in System log
  Get-EventLog -LogName System -Newest 10				

  # Show all Security log events and word wraps output
  Get-Eventlog -LogName Security | ft -wrap			

  # Same as above but with a string search
  Get-Eventlog -LogName Security | ft -wrap | findstr /i StR1nG	

# Get-WinEvent Way

  # Find log type to query
  Get-WinEvent -Listlog *					

  # Check if a user logged on
  Get-Winevent -FilterHashtable @{logname='Security';id='4624'} | ft -Wrap
  Get-Winevent -FilterHashtable @{logname='Security';id='4624'} | ft -Wrap | findstr /i "generated"

  # Check PowerShell Operational Logs
  Get-WinEvent Microsoft-Windows-PowerShell/Operational |Where-Object {$_.Message -ilike "*Out-Default*"} | Format-List
  Get-WinEvent Microsoft-Windows-PowerShell/Operational |Where-Object {$_.Message -ilike "*Pipeline ID = ##"} | Format-List

#---- PowerShell Artifacts

# Capture input/output of Windows PowerShell commands in text-based transcripts
start-transcript

# View PowerShell Console History
Get-History

# View entire PowerShell History
Get-Content "C:\users\$env:username\AppData\Roaming\Microsoft\Windows\PowerShell\PSReadline\ConsoleHost_history.txt"

# Enable Script Block Logging
reg.exe add HKLM\SOFTWARE\Wow6432Node\Policies\Microsoft\Windows\PowerShell\ScriptBlockLogging\ /v EnableScriptBlockLogging /t REG_DWORD /d 1 /f
