# File:     volatility.ps1
# Name:     Joseph Gerwing
# Date:     20200904
# Desc:     Demonstrate usage of the standalone version of Volatility to execute memory analysis
# Usage:    powershell_ise.exe .\volatility.ps1 (Be in an elevated PowerShell ISE prompt)
# Note1:    Script is meant to be ran incrementally using PowerShell ISE's 'run selection (F8)'
# Note2:    All Volatility demos are completed from the Admin_Station while logged in as john.huntsman

#---- Setup Tasks on Admin-Station

#-- Create variables for simpler path referencing
$JOHN = 'C:\Users\john.huntsman\Desktop\Memory Analysis'
$DESKTOP = 'C:\Users\Public\Desktop\Memory'

#-- Navigate to $DESKTOP and extract archive contents to $JOHN
cd $DESKTOP
Expand-Archive .\memdump.zip $JOHN -Force
Expand-archive .\vol_standalone.zip $JOHN

#-- Verify key files from previous extractions (cridex.vmem, volatility_2.6_win64_standalone and volatility_2.6_win64_standalone.exe)
gci $JOHN                                       
gci $JOHN\volatility_2.6_win64_standalone

#-- Create another variable for simpler path referencing
$INFO = "$JOHN\volatility_2.6_win64_standalone" 

#-- Move executable from $INFO to $JOHN for ease of typing
mv $INFO\volatility_2.6_win64_standalone.exe $JOHN

#---- Volatility Demo Commands
cd $JOHN # Be in the dir for the executable

#-- List all modules available to Volatility
.\volatility_2.6_win64_standalone.exe -h
.\volatility_2.6_win64_standalone.exe --help

#-- Volatility syntax for specifying a filename (i.e for a memory image/dump)
.\volatility_2.6_win64_standalone.exe -f [FILENAME]
.\volatility_2.6_win64_standalone.exe --filename [FILENAME]

#-- Plugin: Imageinfo *ALWAYS USE FIRST*
#-- Note: Use to determine what profile to use based on output for "Suggested Profile(s) :"
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" imageinfo

#-- Volatility syntax for a profile (--profile=<profile>)
#-- Note: While PowerShell is case insensitive, Volatility is not. Type <profile> in exactly as seen from "imageinfo" output.
#-- Note: "-h" provides all the available plugins for the profile "WinXPSP2x86"
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 -h

#-- Plugin: pslist
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 pslist

#-- Plugin: psscan
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 psscan

#-- Plugin: psxview
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 psxview

#-- Plugin: pstree
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 pstree

#-- Plugin: procdump
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 procdump -p 1484 -D "$JOHN\"

  # Hash the executable.  Copy and Paste hash into the "search" function of www.virustotal.com
  get-filehash .\executable.1484.exe

#-- Plugin: memdump
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 memdump -p 1484 -D "$JOHN\"

  # Utilize sysinternals to read the .dmp file
  net user * \\live.sysinternals.com\tools
  Z:  #Change dir to whatever drive letter is set for sysinternals
  .\strings.exe -accepteula "$JOHN\executable.1484.exe"
  C:  #Change dir back to the standalone volatility tool

#-- Plugin: connections
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 connections

#-- Plugin: connscan
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 connscan

#-- Plugin: cmdscan
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 cmdscan

#-- Plugin: consoles
.\volatility_2.6_win64_standalone.exe -f ".\cridex.vmem" --profile=WinXPSP2x86 consoles