#!/bin/bash

# File:         login.sh
# Name:         Joseph Gerwing
# Date:         20200224
# Desc:         Automate logons for CCTC-OS instances
# Usage:        ./login.sh
# Note:         Populate variables in 'LOGIN VARIABLES' section first!

#### COLOR VARIABLES ########################################
LC_COLOR="\e[48;5;8m\e[38;5;46m"     # (l)inux (c)ommand
LPW_COLOR="\e[48;5;46m\e[38;5;8m"    # (l)inux (p)ass(w)ord
LI_COLOR="\e[38;5;46m"               # (l)inux (i)nstance
WC_COLOR="\e[48;5;7m\e[38;5;27m"     # (w)indows (c)ommand
WPW_COLOR="\e[48;5;27m\e[38;5;7m"    # (w)indows (p)ass(w)ord
WI_COLOR="\e[38;5;27m"               # (w)indows (i)nstance
NC="\e[0m"                           # clear formating


#### LOGIN VARIABLES #########################################
# Student ID - provided by instructor
STUDENT_ID=   

# Linux OpStation
LO_USER=        # Username
LO_FIP=         # Floating_IP
LO_PW=          # Password

# Windows OpStation
WO_USER=        # Username
WO_FIP=         # Floating IP
WO_PW=          # Password

# Admin Station
WA_USER=        # Username
WA_FIP=         # Floating IP
WA_PW=          # Password

# Workstation1
W1_USER=        # Username
W1_FIP=         # Floating IP
W1_PW=          # Password

# Linux_Student_Environment - Different Usernames per challenge
LSE_FIP=        # Floating_IP
LSE_PW=         # Password

# Linux_Student_Images
LSI_USER=       # Username
LSI_FIP=        # Floating_IP
LSI_PW=         # Password




#### Functions  #########################################
lnx_opstation () {
clear
echo -e "\n\n"
echo -e "${LI_COLOR}Linux_OpStation${NC}"
echo -e "${LC_COLOR}ssh -X ${LO_USER}@${LO_FIP}${NC}${LPW_COLOR}${LO_PW}${NC}"
ssh -X $LO_USER@$LO_FIP
echo -e "\n\n"
}

win_opstation () {
clear
echo -e "\n\n"
echo -e "${WI_COLOR}Windows_OpStation${NC}"
echo -e "${WC_COLOR}xfreerdp /u:$WO_USER /v:$WO_FIP /size:1920x1020 +glyph-cache +clipboard${NC}${WPW_COLOR}${WO_PW}${NC}"
xfreerdp /u:$WO_USER /v:$WO_FIP /size:1920x1020 +glyph-cache +clipboard
echo -e "\n\n"
}

admin_station () {
clear
echo -e "\n\n"
echo -e "${WI_COLOR}Admin_Station${NC}"
echo -e "${WC_COLOR}xfreerdp /u:$WA_USER /v:$WA_FIP /size:1920x1020 +glyph-cache +clipboard${NC}${WPW_COLOR}${WA_PW}${NC}"
xfreerdp /u:$WA_USER /v:$WA_FIP /size:1920x1020 +glyph-cache +clipboard
echo -e "\n\n"
}

workstation1 () {
clear
echo -e "\n\n"
echo -e "${WI_COLOR}Workstation1${NC}"
echo -e "${WC_COLOR}xfreerdp /u:$W1_USER /v:$W1_FIP /size:1920x1020 +glyph-cache +clipboard${NC}${WPW_COLOR}${W1_PW}${NC}"
xfreerdp /u:$W1_USER /v:$W1_FIP /size:1920x1020 +glyph-cache +clipboard
echo -e "\n\n"
}

lnx_stu_env () {
clear
echo -e "\n\n"
echo -n "Enter value for 'XX' for userXX (from CTFd challenge) and press [Enter]: "
read x
echo
echo -e "${LI_COLOR}Linux_Student_Environment${NC}"
echo -e "${LC_COLOR}ssh -X user${x}@$LSE_FIP${NC}${LPW_COLOR}${LSE_PW}${NC}"
ssh -X user${x}@$LSE_FIP
echo -e "\n\n"
}

lnx_stu_img () {
clear
echo -e "\n\n"
echo -e "${LI_COLOR}Linux_Student_Images${NC}"
echo -e "${LC_COLOR}ssh -X ${LSI_USER}@${LSI_FIP}${NC}${LPW_COLOR}${LSI_PW}${NC}"
ssh -X $LSI_USER@$LSI_FIP
echo -e "\n\n"
}

ip_cut () {
clear
echo -e "\n\n"
echo -e "\e[4mINSTANCE FLOATING_IP CREDENTIALS\e[0m" >> cut.txt
echo "Linux_OpStation $LO_FIP ${LO_USER}:${LO_PW}" >> cut.txt
echo "Windows_OpStation $WO_FIP ${WO_USER}:${WO_PW}" >> cut.txt
echo "Admin $WA_FIP ${WA_USER}:${WA_PW}" >> cut.txt
echo "Workstation1 $W1_FIP ${W1_USER}:${W1_PW}" >> cut.txt
echo "Linux_Student_Environment $LSE_FIP userXX:${LSE_PW}" >> cut.txt
echo "Linux_Student_Images $LSI_FIP ${LSI_USER}:${LSI_PW}" >> cut.txt

cat cut.txt | column -t
rm cut.txt
echo -e "\n\n"
}

#### SELECTION MENU  #########################################
mainMenu () {

clear

while :
do

	echo
	echo "Choose from the following options:"
	echo "----------------------------------"
	echo "   [1] Linux-OpStation"
	echo "   [2] Windows-OpStation"
	echo "   [3] Admin_Station"
	echo "   [4] Workstation1"
	echo "   [5] Linux_Student_Environment"
	echo "   [6] Linux_Student_Images"
	echo "   [7] Show IP cutsheet"
	echo
	echo "   [X] to Exit : [C] to Clear the Screen" && echo

	read -p "Choice: " choice
	echo

	case $choice in
		1) lnx_opstation
			;;
		2) win_opstation
			;;
		3) admin_station
			;;
		4) workstation1
			;;
		5) lnx_stu_env
			;;
		6) lnx_stu_img
			;;
		7) ip_cut
		    ;;
		[xX]) return 0
			;;
		[cC]) clear
			;;
		*) echo "Please enter a valid option"
			;;
	esac
done
}

# RUN THE PROGRAM
mainMenu
